@@ -25,9 +25,15 @@ logformat='[%(levelname)s] [%(filename)s:%(funcName)s:%(lineno)d] %(message)s'
 if args.verbose:
     logformat='[%(levelname)s] [%(filename)s:%(funcName)s:%(lineno)d] %(message)s'
 if args.debug:
-    logging.basicConfig(filename="/var/log/ssh-key-retriever.log", level=os.environ.get("LOG", "DEBUG"), format = logformat)
+    try:
+        logging.basicConfig(filename="/var/log/ssh-key-retriever.log", level=os.environ.get("LOG", "DEBUG"), format = logformat)
+    except PermissionError:
+        logging.basicConfig(level=os.environ.get("LOG", "DEBUG"), format = logformat)
 else:
-    logging.basicConfig(filename="/var/log/ssh-key-retriever.log", level=os.environ.get("LOG", "INFO"), format = logformat)
+    try:
+        logging.basicConfig(filename="/var/log/ssh-key-retriever.log", level=os.environ.get("LOG", "INFO"), format = logformat)
+    except PermissionError:
+        logging.basicConfig(level=os.environ.get("LOG", "INFO"), format = logformat)
 logger = logging.getLogger(__name__)
 
 
@@ -45,13 +51,13 @@ def get_sshkeys():
         raise ValueError()
 
     sshkeys = get_sshkey_from_external_id(external_id)
-    print (F"{sshkeys}")
     return sshkeys
 
 
 def main():
     sshkeys = get_sshkeys()
-    return sshkeys
+    print (F"{sshkeys}")
+    return 0
 
 
 if __name__ == "__main__":
